@@ -18,21 +18,23 @@ class Literal(Expression):
     body: dict[str, Expression] | list[Expression] | str | float | int | bool | None
 
     def eval(self, entity_type: type[Entity], variables: dict[str, Selectable]) -> sql.atoms.literal.Literal:
-        if self.body is None:
+        body = self.body
+        if body is None:
             type_ = None
-        elif isinstance(self.body, bool):
+        elif isinstance(body, bool):
             type_ = bool
-        elif isinstance(self.body, int):
+        elif isinstance(body, int):
             type_ = int
-        elif isinstance(self.body, float):
+        elif isinstance(body, float):
             type_ = float
-        elif isinstance(self.body, str):
+        elif isinstance(body, str):
             type_ = str
-        elif isinstance(self.body, list):
+        elif isinstance(body, list):
             type_ = list
+            body = [v.eval(entity_type, variables).value for v in body]
         else:
-            raise TypeError(f"Unsupported literal type: {type(self.body)}")
-        return sql.atoms.literal.Literal(type_=type_, value=self.body)
+            raise TypeError(f"Unsupported literal type: {type(body)}")
+        return sql.atoms.literal.Literal(type_=type_, value=body)
 
     def shortcut(self) -> str:
         return self._shortcut(self.body)
